summaryrefslogtreecommitdiffstats
path: root/src/svnqt/svnstream.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/svnqt/svnstream.hpp')
-rw-r--r--src/svnqt/svnstream.hpp23
1 files changed, 11 insertions, 12 deletions
diff --git a/src/svnqt/svnstream.hpp b/src/svnqt/svnstream.hpp
index 89276c8..6a14640 100644
--- a/src/svnqt/svnstream.hpp
+++ b/src/svnqt/svnstream.hpp
@@ -22,7 +22,7 @@
#include "svnqt/svnqt_defines.hpp"
-#include <qstring.h>
+#include <tqstring.h>
#include <svn_io.h>
struct svn_client_ctx_t;
@@ -36,7 +36,7 @@ class SvnStream_private;
@author Rajko Albrecht <ral@alwins-world.de>
@short wrapper class around the svn_stream_t structure
*/
-class SVNQT_EXPORT SvnStream{
+class SVNTQT_EXPORT SvnStream{
friend class SvnStream_private;
public:
//! Constructor
@@ -66,7 +66,7 @@ public:
\param data the data to written
\param max maximum data to write
\return should return the amount of data real written, in case of error must return -1
- \sa setError(int ioError), setError(const QString&error), read(char*data,const unsigned long max)
+ \sa setError(int ioError), setError(const TQString&error), read(char*data,const unsigned long max)
*/
virtual long write(const char*data,const unsigned long max);
//! read operation
@@ -75,7 +75,7 @@ public:
\param data target array where to store the read
\param max maximum byte count to read
\return amount of data read or -1 in case of error
- \sa setError(int ioError), setError(const QString&error), write(const char*data,const unsigned long max)
+ \sa setError(int ioError), setError(const TQString&error), write(const char*data,const unsigned long max)
*/
virtual long read(char*data,const unsigned long max);
@@ -83,7 +83,7 @@ public:
/*!
\return a human readable message about the reason the last operation failed.
*/
- virtual const QString& lastError()const;
+ virtual const TQString& lastError()const;
//! is that stream usable
/*!
Gives information about if the stream object is usable. May if the file is real open or such.
@@ -100,13 +100,12 @@ protected:
write and/or read if them will return -1 (for error)
\param error the errormessage assigned.
*/
- virtual void setError(const QString&error)const;
+ virtual void setError(const TQString&error)const;
//! set the internal error
- /*! \param ioError error code from QIODevide::status
+ /*! \param ioError error code from TQIODevide::status
*/
-#if QT_VERSION < 0x040000
+
virtual void setError(int ioError)const;
-#endif
protected:
int cancelElapsed()const;
@@ -120,8 +119,8 @@ private:
class SvnByteStream_private;
-//! a class let subversion print into a QByteArray
-class SVNQT_EXPORT SvnByteStream:public SvnStream
+//! a class let subversion print into a TQByteArray
+class SVNTQT_EXPORT SvnByteStream:public SvnStream
{
public:
//! constructor
@@ -146,7 +145,7 @@ public:
/*!
\return the internal stored data
*/
- QByteArray content()const;
+ TQByteArray content()const;
//! checks if the buffer is usable.
/*!
* \return true if data may written, false if not, in that case a errormessage will set.